<?php

namespace Drupal\comma_separated_string_widget\Plugin\Field\FieldWidget;

use Drupal\Core\Field\Plugin\Field\FieldWidget\StringTextfieldWidget;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'string_textfield' widget.
 *
 * @FieldWidget(
 *   id = "comma_separated_string_textfield",
 *   label = @Translation("Textfield (comma separated values)"),
 *   field_types = {
 *     "string"
 *   },
 *   multiple_values = TRUE
 * )
 */
class CommaSeparatedStringWidget extends StringTextfieldWidget {

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    $values = parent::massageFormValues($values, $form, $form_state);
    // Explode the single value into multiple values.
    $items = array_map('trim', explode(',', $values['value']));
    $items = array_values(array_filter($items));
    return array_map(function ($item) {
      return ['value' => $item];
    }, $items);
  }

}
