<?php

namespace Drupal\Test\comma_separated_string_widget\Unit\Plugin\Field\FieldWidget;

use Drupal\comma_separated_string_widget\Plugin\Field\FieldWidget\CommaSeparatedStringWidget;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Tests\UnitTestCase;

/**
 * Tests the CommaSeparatedStringWidget class.
 *
 * @group comma_separated_string_widget
 * @coversDefaultClass \Drupal\comma_separated_string_widget\Plugin\Field\FieldWidget\CommaSeparatedStringWidget
 */
class CommaSeparatedStringWidgetTest extends UnitTestCase {

  /**
   * The system under test.
   *
   * @var \Drupal\comma_separated_string_widget\Plugin\Field\FieldWidget\CommaSeparatedStringWidget
   */
  private $widget;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $plugin_id = 'comma_separated_string_textfield';
    $plugin_definition = [];
    $field_definition = $this->prophesize(FieldDefinitionInterface::class);
    $settings = [];
    $third_party_settings = [];
    $this->widget = new CommaSeparatedStringWidget(
      $plugin_id,
      $plugin_definition,
      $field_definition->reveal(),
      $settings,
      $third_party_settings
    );
  }

  /**
   * Tests the massageFormValues method.
   *
   * @param string $user_input
   *   The provided user input.
   * @param array $expected
   *   The expected output values.
   *
   * @covers ::massageFormValues
   * @dataProvider massageFormValuesProvider
   */
  public function testMassageFormValues(string $user_input, array $expected): void {
    $form_state = $this->prophesize(FormStateInterface::class);
    $actual = $this->widget->massageFormValues(['value' => $user_input], [], $form_state->reveal());
    $this->assertArrayEquals($expected, $actual);
  }

  /**
   * Data provider for testMassageFormValues.
   */
  public function massageFormValuesProvider(): array {
    return [
      [
        'first,second, third  ,	fourth',
        [
          ['value' => 'first'],
          ['value' => 'second'],
          ['value' => 'third'],
          ['value' => 'fourth'],
        ],
      ],
      ['', []],
      [',,,one,,one', [['value' => 'one'], ['value' => 'one']]],
    ];
  }

}
